@@ -1,6 +1,7 @@
 pub mod create_tunnel;
 mod data_structures;
+pub mod delete_tunnel;
+pub mod list_tunnels;
 pub mod route_dns;
 
 pub use data_structures::*;
-
